Learn R Programming

rmdpartials (version 0.6.5)

as.partial: Convert text or file to a partial

Description

This adds the knit_asis class to a markdown chunk, so that it can be rendered in the viewer and simply echoed in other knitr chunks. Won't preserve figures unless the path happens to be the same or you explicitly pass it to the knit_meta argument.

Usage

as.partial(text = NULL, knit_meta = list())

Value

Returns its input as text with class "knit_asis"

Arguments

text

will be returned with the class "knit_asis"

knit_meta

you can pass a path to figures and other resources here

Examples

Run this code
my_partial <- as.partial("## Headline
Text")

Run the code above in your browser using DataLab