Show the estimated coefficients in a regression and diagnostics
Source:R/regression_diagnostics.R
regression_diagnostics.RdShow the estimated coefficients in a regression and diagnostics
Arguments
- regression
an lm object
- ...
passed to
partial()
Examples
if (FALSE) { # \dontrun{
# will generate files in a temporary directory
if(!requireNamespace("pkgdown", quietly = TRUE) || !pkgdown::in_pkgdown()) {
data("ChickWeight")
regression <- lm(weight ~ Time, data = ChickWeight)
regression_diagnostics(regression)
}
} # }