Learn R Programming

rmdpartials (version 0.6.5)

print.knit_asis: Print knit_asis as rendered HTML in the viewer

Description

Print knit_asis as rendered HTML in the viewer

Usage

# S3 method for knit_asis
print(x, ...)

Value

Invisibly returns its input, either prints its input or sends it to a viewer, if one is defined

Arguments

x

the knit_asis object

...

ignored

Examples

Run this code
text <- paste(c("### Headline",
"Text"), collapse = "\n")
print(knitr::asis_output(text))

Run the code above in your browser using DataLab