powered by
knit_asis
Print knit_asis as rendered HTML in the viewer
# S3 method for knit_asis print(x, ...)
Invisibly returns its input, either prints its input or sends it to a viewer, if one is defined
the knit_asis object
ignored
text <- paste(c("### Headline", "Text"), collapse = "\n") print(knitr::asis_output(text))
Run the code above in your browser using DataLab