Learn R Programming

rmdpartials (version 0.6.5)

regression_diagnostics: Show the estimated coefficients in a regression and diagnostics

Description

Show the estimated coefficients in a regression and diagnostics

Usage

regression_diagnostics(regression, ...)

Value

Returns markdown/HTML text with class "knit_asis"

Arguments

regression

an lm object

...

passed to partial()

Examples

Run this code
if (FALSE) {
# will generate files in a temporary directory
if(!requireNamespace("pkgdown", quietly = TRUE) || !pkgdown::in_pkgdown()) {
data("ChickWeight")
regression <- lm(weight ~ Time, data = ChickWeight)
regression_diagnostics(regression)
}
}

Run the code above in your browser using DataLab